# Write your code here :-)
from machine import Pin, ADC, I2C
import math
import _thread
import network
import time
import json
import kidbright as kb
from umqtt.robust import MQTTClient
import machine

from config import (
    WIFI_SSID,
    WIFI_PASS,
    MQTT_BROKER,
    MQTT_USER,
    MQTT_PASS
)

import dht

led_wifi = Pin(2, Pin.OUT)
led_wifi.value(1)  # turn the red led off

led_iot = Pin(12, Pin.OUT)
led_iot.value(1)   # turn the green led off

kb.init()

wlan = network.WLAN(network.STA_IF)
wlan.active(True)
wlan.connect(WIFI_SSID, WIFI_PASS)

while not wlan.isconnected():
    time.sleep(0.5)
led_wifi.value(0)

mqtt = MQTTClient(client_id="",
                  server=MQTT_BROKER,
                  user=MQTT_USER,
                  password=MQTT_PASS)
mqtt.connect()
led_iot.value(0)

moisture_sensor_pin = 33

soil = ADC(Pin(moisture_sensor_pin))
soil.atten(ADC.ATTN_11DB)
air = dht.DHT11(Pin(32))
light = ADC(Pin(36))

class LinearInterpolation:
    def __init__(self, x0, x1, y0, y1, clip=True):
        self.x0 = x0
        self.x1 = x1
        self.y0 = y0
        self.y1 = y1
        self.clip = clip

    def map(self, x):
        if self.clip:
            x = max(x, self.x0)
            x = min(x, self.x1)
        return (x-self.x0)/(self.x1-self.x0)*(self.y1-self.y0) + self.y0

# _thread.start_new_thread(task, ())

while True:
        moisture_value = soil.read()
        moisture_percentage = (moisture_value / 4095) * 100
        moisture = moisture_percentage
        print("Soil : {:.2f}%".format(moisture_percentage))

        air.measure()
        humidity = air.humidity()
        temperature = air.temperature()
        print("Humidity: ", humidity, " %")
        print("Temperature: ", temperature, " c")

        Va = (light.read()*1.1)/4095
        if Va == 0:
            Va = 0.001
        Rldr = (Va*33000)/(3.3-Va)
        lerp = LinearInterpolation(0, 4, 2, -1)
        RldrK = Rldr/1000
        Log_Rldr = math.log10(RldrK)
        Lux = lerp.map(Log_Rldr)
        Log_Lux = math.log10(Lux)
        light_lux = round(Log_Lux*1000,2)
        print("Light: ", light_lux, " lux")

        payload = {
            "soil": moisture,
            "humidity": humidity,
            "temperature": temperature,
            "light": light_lux
        }
        mqtt.publish("daq2023/group2", json.dumps(payload))
        time.sleep(3600)
        machine.reset()
